Légilibre
Le droit libre

# $title

Ici sont publiées les anomalies détectées par legi.py dans la base de données des lois françaises (LEGI), pour encourager la DILA à les corriger.

## Situation actuelle

$last_fname liste $last_count anomalies.

## Historique des anomalies

Le graphique ci-dessous représente le nombre d'anomalies trouvées dans chaque version de la base LEGI, à partir du 6 avril 2016.
Vous pouvez cliquer sur une colonne pour voir la liste d'anomalies correspondante, ou visiter le répertoire qui contient les fichiers.

$graph